==> openshift-model-monitoring-5.9.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/NamespaceSelectorBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NamespaceSelectorBuilder extends io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector,io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorBuilder>{
  public NamespaceSelectorBuilder() {
    this(false);
  }
  public NamespaceSelectorBuilder(java.lang.Boolean validationEnabled) {
    this(new NamespaceSelector(), validationEnabled);
  }
  public NamespaceSelectorBuilder(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public NamespaceSelectorBuilder(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NamespaceSelector(), validationEnabled);
  }
  public NamespaceSelectorBuilder(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector instance) {
    this(fluent, instance, false);
  }
  public NamespaceSelectorBuilder(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAny(instance.getAny()); 
    fluent.withMatchNames(instance.getMatchNames()); 
    this.validationEnabled = validationEnabled; 
  }
  public NamespaceSelectorBuilder(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector instance) {
    this(instance,false);
  }
  public NamespaceSelectorBuilder(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAny(instance.getAny()); 
    this.withMatchNames(instance.getMatchNames()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector build() {
    NamespaceSelector buildable = new NamespaceSelector(fluent.getAny(),fluent.getMatchNames());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamespaceSelectorBuilder that = (NamespaceSelectorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/NamespaceSelectorBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NamespaceSelectorBuilder extends io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector,io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorBuilder>{
  public NamespaceSelectorBuilder() {
    this(false);
  }
  public NamespaceSelectorBuilder(java.lang.Boolean validationEnabled) {
    this(new NamespaceSelector(), validationEnabled);
  }
  public NamespaceSelectorBuilder(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public NamespaceSelectorBuilder(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NamespaceSelector(), validationEnabled);
  }
  public NamespaceSelectorBuilder(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector instance) {
    this(fluent, instance, false);
  }
  public NamespaceSelectorBuilder(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAny(instance.getAny()); 
    fluent.withMatchNames(instance.getMatchNames()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NamespaceSelectorBuilder(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector instance) {
    this(instance,false);
  }
  public NamespaceSelectorBuilder(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAny(instance.getAny()); 
    this.withMatchNames(instance.getMatchNames()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector build() {
    NamespaceSelector buildable = new NamespaceSelector(fluent.getAny(),fluent.getMatchNames());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamespaceSelectorBuilder that = (NamespaceSelectorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
